---
name: Release issue template
about: Final checklist before a release
title: 'Release xx.x checklist'
labels: ''
assignees: ''

---

Before the next version of autoreduction can be released, the following must be checked:

* [ ] Inform dev team of code freeze
* [ ] Create release branch
  * [ ] Update version number in setup.py AND readme front page
* [ ] Identify key issues for the release
* [ ] Resolve remaining issues
* [ ] Development environment smoke test
* [ ] Production environment smoke test
* [ ] Inform customers
* [ ] Release

Check the [Release documentation](https://github.com/autoreduction/autoreduce/wiki/Releases) for further details on each stage
